<?php

namespace Drupal\connectid;

use ConnectID\Api\DataModel\CouponType;
use ConnectID\Api\DataModel\CouponTypeList;
use ConnectID\Api\DataModel\Order;
use ConnectID\Api\DataModel\OrderStatus;
use ConnectID\Api\DataModel\ProductTypeList;
use Drupal\Core\Url;

/**
 * Interface ApiServiceInterface.
 */
interface ApiServiceInterface {

  /**
   * Lists the Products.
   *
   * @see https://doc.mediaconnect.no/doc/ConnectID/#tag/Product/paths/~1v1~1customer~1product/get
   *
   * @return \ConnectID\Api\DataModel\ProductTypeList
   */
  public function getProducts(): ProductTypeList;


  /**
   * Lists the coupons for a given product.
   *
   * @see https://doc.mediaconnect.no/doc/ConnectID/#tag/Coupon/paths/~1v1~1client~1coupon~1{productId}/get
   *
   * @param string $productName
   *
   * @return \ConnectID\Api\DataModel\CouponTypeList
   */
  public function getProductCoupons(string $productName): CouponTypeList;

  public function getCoupon(string $couponId): ?CouponType;

  public function registerOrder(Order $order): Order;

  public function getOrderFulfillmentUrl(Order $order, Url $successUrl = NULL, Url $errorUrl = NULL): Url;

  public function getOrderStatus(string $orderId): ?OrderStatus;
}
